# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class NumbersToInvestigate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'numbers': 'list[str]'
    }

    attribute_map = {
        'numbers': 'numbers'
    }

    def __init__(self, numbers=None, local_vars_configuration=None):  # noqa: E501
        """NumbersToInvestigate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._numbers = None
        self.discriminator = None

        self.numbers = numbers

    @property
    def numbers(self):
        """Gets the numbers of this NumbersToInvestigate.  # noqa: E501

        Array of phone numbers  # noqa: E501

        :return: The numbers of this NumbersToInvestigate.  # noqa: E501
        :rtype: list[str]
        """
        return self._numbers

    @numbers.setter
    def numbers(self, numbers):
        """Sets the numbers of this NumbersToInvestigate.

        Array of phone numbers  # noqa: E501

        :param numbers: The numbers of this NumbersToInvestigate.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and numbers is None:  # noqa: E501
            raise ValueError("Invalid value for `numbers`, must not be `None`")  # noqa: E501

        self._numbers = numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NumbersToInvestigate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NumbersToInvestigate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class Omnimessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        'messages': 'list[OneOfViberSMSWhatsAppTelegram]',
        'dlr_url': 'str',
        'text_store': 'TextStore',
        'time_to_send': 'datetime'
    }

    attribute_map = {
        'to': 'to',
        'messages': 'messages',
        'dlr_url': 'dlr_url',
        'text_store': 'text_store',
        'time_to_send': 'time_to_send'
    }

    def __init__(self, to=None, messages=None, dlr_url=None, text_store=None, time_to_send=None, local_vars_configuration=None):  # noqa: E501
        """Omnimessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._to = None
        self._messages = None
        self._dlr_url = None
        self._text_store = None
        self._time_to_send = None
        self.discriminator = None

        self.to = to
        self.messages = messages
        if dlr_url is not None:
            self.dlr_url = dlr_url
        if text_store is not None:
            self.text_store = text_store
        if time_to_send is not None:
            self.time_to_send = time_to_send

    @property
    def to(self):
        """Gets the to of this Omnimessage.  # noqa: E501

        Phone number in e.164 format  # noqa: E501

        :return: The to of this Omnimessage.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this Omnimessage.

        Phone number in e.164 format  # noqa: E501

        :param to: The to of this Omnimessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def messages(self):
        """Gets the messages of this Omnimessage.  # noqa: E501

        An array of messages  # noqa: E501

        :return: The messages of this Omnimessage.  # noqa: E501
        :rtype: list[OneOfViberSMSWhatsAppTelegram]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """Sets the messages of this Omnimessage.

        An array of messages  # noqa: E501

        :param messages: The messages of this Omnimessage.  # noqa: E501
        :type: list[OneOfViberSMSWhatsAppTelegram]
        """
        if self.local_vars_configuration.client_side_validation and messages is None:  # noqa: E501
            raise ValueError("Invalid value for `messages`, must not be `None`")  # noqa: E501

        self._messages = messages

    @property
    def dlr_url(self):
        """Gets the dlr_url of this Omnimessage.  # noqa: E501

        URL where the delivery report will be sent  # noqa: E501

        :return: The dlr_url of this Omnimessage.  # noqa: E501
        :rtype: str
        """
        return self._dlr_url

    @dlr_url.setter
    def dlr_url(self, dlr_url):
        """Sets the dlr_url of this Omnimessage.

        URL where the delivery report will be sent  # noqa: E501

        :param dlr_url: The dlr_url of this Omnimessage.  # noqa: E501
        :type: str
        """

        self._dlr_url = dlr_url

    @property
    def text_store(self):
        """Gets the text_store of this Omnimessage.  # noqa: E501


        :return: The text_store of this Omnimessage.  # noqa: E501
        :rtype: TextStore
        """
        return self._text_store

    @text_store.setter
    def text_store(self, text_store):
        """Sets the text_store of this Omnimessage.


        :param text_store: The text_store of this Omnimessage.  # noqa: E501
        :type: TextStore
        """

        self._text_store = text_store

    @property
    def time_to_send(self):
        """Gets the time_to_send of this Omnimessage.  # noqa: E501

        Optional parameter for sending messages at some specific time in the future.   Time must be specified in the ISO-8601 format.   If no timezone is specified, then the timezone is assumed to be UTC    Examples:    * Time specified with timezone: 2018-06-22T09:05:07+00:00 Time specified in UTC: 2018-06-22T09:05:07Z   * Time specified without timezone: 2018-06-22T09:05 (equivalent to 2018-06-22T09:05+00:00)  # noqa: E501

        :return: The time_to_send of this Omnimessage.  # noqa: E501
        :rtype: datetime
        """
        return self._time_to_send

    @time_to_send.setter
    def time_to_send(self, time_to_send):
        """Sets the time_to_send of this Omnimessage.

        Optional parameter for sending messages at some specific time in the future.   Time must be specified in the ISO-8601 format.   If no timezone is specified, then the timezone is assumed to be UTC    Examples:    * Time specified with timezone: 2018-06-22T09:05:07+00:00 Time specified in UTC: 2018-06-22T09:05:07Z   * Time specified without timezone: 2018-06-22T09:05 (equivalent to 2018-06-22T09:05+00:00)  # noqa: E501

        :param time_to_send: The time_to_send of this Omnimessage.  # noqa: E501
        :type: datetime
        """

        self._time_to_send = time_to_send

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Omnimessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Omnimessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class SyncNumberLookupResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'number': 'str',
        'roaming': 'bool',
        'ported': 'bool',
        'roaming_network': 'MobileNetwork',
        'current_network': 'MobileNetwork',
        'original_network': 'MobileNetwork',
        'ported_network': 'MobileNetwork',
        'status': 'str',
        'error': 'object'
    }

    attribute_map = {
        'number': 'number',
        'roaming': 'roaming',
        'ported': 'ported',
        'roaming_network': 'roamingNetwork',
        'current_network': 'currentNetwork',
        'original_network': 'originalNetwork',
        'ported_network': 'portedNetwork',
        'status': 'status',
        'error': 'error'
    }

    def __init__(self, number=None, roaming=None, ported=None, roaming_network=None, current_network=None, original_network=None, ported_network=None, status=None, error=None, local_vars_configuration=None):  # noqa: E501
        """SyncNumberLookupResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._number = None
        self._roaming = None
        self._ported = None
        self._roaming_network = None
        self._current_network = None
        self._original_network = None
        self._ported_network = None
        self._status = None
        self._error = None
        self.discriminator = None

        self.number = number
        self.roaming = roaming
        self.ported = ported
        self.roaming_network = roaming_network
        self.current_network = current_network
        self.original_network = original_network
        self.ported_network = ported_network
        if status is not None:
            self.status = status
        if error is not None:
            self.error = error

    @property
    def number(self):
        """Gets the number of this SyncNumberLookupResult.  # noqa: E501

        Phone number in e.164 format  # noqa: E501

        :return: The number of this SyncNumberLookupResult.  # noqa: E501
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this SyncNumberLookupResult.

        Phone number in e.164 format  # noqa: E501

        :param number: The number of this SyncNumberLookupResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def roaming(self):
        """Gets the roaming of this SyncNumberLookupResult.  # noqa: E501

        Indicates if a number is roaming  # noqa: E501

        :return: The roaming of this SyncNumberLookupResult.  # noqa: E501
        :rtype: bool
        """
        return self._roaming

    @roaming.setter
    def roaming(self, roaming):
        """Sets the roaming of this SyncNumberLookupResult.

        Indicates if a number is roaming  # noqa: E501

        :param roaming: The roaming of this SyncNumberLookupResult.  # noqa: E501
        :type: bool
        """

        self._roaming = roaming

    @property
    def ported(self):
        """Gets the ported of this SyncNumberLookupResult.  # noqa: E501

        Indicates if a number is ported  # noqa: E501

        :return: The ported of this SyncNumberLookupResult.  # noqa: E501
        :rtype: bool
        """
        return self._ported

    @ported.setter
    def ported(self, ported):
        """Sets the ported of this SyncNumberLookupResult.

        Indicates if a number is ported  # noqa: E501

        :param ported: The ported of this SyncNumberLookupResult.  # noqa: E501
        :type: bool
        """

        self._ported = ported

    @property
    def roaming_network(self):
        """Gets the roaming_network of this SyncNumberLookupResult.  # noqa: E501


        :return: The roaming_network of this SyncNumberLookupResult.  # noqa: E501
        :rtype: MobileNetwork
        """
        return self._roaming_network

    @roaming_network.setter
    def roaming_network(self, roaming_network):
        """Sets the roaming_network of this SyncNumberLookupResult.


        :param roaming_network: The roaming_network of this SyncNumberLookupResult.  # noqa: E501
        :type: MobileNetwork
        """

        self._roaming_network = roaming_network

    @property
    def current_network(self):
        """Gets the current_network of this SyncNumberLookupResult.  # noqa: E501


        :return: The current_network of this SyncNumberLookupResult.  # noqa: E501
        :rtype: MobileNetwork
        """
        return self._current_network

    @current_network.setter
    def current_network(self, current_network):
        """Sets the current_network of this SyncNumberLookupResult.


        :param current_network: The current_network of this SyncNumberLookupResult.  # noqa: E501
        :type: MobileNetwork
        """

        self._current_network = current_network

    @property
    def original_network(self):
        """Gets the original_network of this SyncNumberLookupResult.  # noqa: E501


        :return: The original_network of this SyncNumberLookupResult.  # noqa: E501
        :rtype: MobileNetwork
        """
        return self._original_network

    @original_network.setter
    def original_network(self, original_network):
        """Sets the original_network of this SyncNumberLookupResult.


        :param original_network: The original_network of this SyncNumberLookupResult.  # noqa: E501
        :type: MobileNetwork
        """

        self._original_network = original_network

    @property
    def ported_network(self):
        """Gets the ported_network of this SyncNumberLookupResult.  # noqa: E501


        :return: The ported_network of this SyncNumberLookupResult.  # noqa: E501
        :rtype: MobileNetwork
        """
        return self._ported_network

    @ported_network.setter
    def ported_network(self, ported_network):
        """Sets the ported_network of this SyncNumberLookupResult.


        :param ported_network: The ported_network of this SyncNumberLookupResult.  # noqa: E501
        :type: MobileNetwork
        """

        self._ported_network = ported_network

    @property
    def status(self):
        """Gets the status of this SyncNumberLookupResult.  # noqa: E501

        Status of the phone number  # noqa: E501

        :return: The status of this SyncNumberLookupResult.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SyncNumberLookupResult.

        Status of the phone number  # noqa: E501

        :param status: The status of this SyncNumberLookupResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["ON", "OFF", "INVALID", "UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def error(self):
        """Gets the error of this SyncNumberLookupResult.  # noqa: E501

        Indicates if any error occurred while handling the request  # noqa: E501

        :return: The error of this SyncNumberLookupResult.  # noqa: E501
        :rtype: object
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this SyncNumberLookupResult.

        Indicates if any error occurred while handling the request  # noqa: E501

        :param error: The error of this SyncNumberLookupResult.  # noqa: E501
        :type: object
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncNumberLookupResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SyncNumberLookupResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class GroupResponseFields(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'created_on': 'str',
        'contacts_count': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'created_on': 'createdOn',
        'contacts_count': 'contactsCount'
    }

    def __init__(self, id=None, name=None, created_on=None, contacts_count=None, local_vars_configuration=None):  # noqa: E501
        """GroupResponseFields - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._created_on = None
        self._contacts_count = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.created_on = created_on
        self.contacts_count = contacts_count

    @property
    def id(self):
        """Gets the id of this GroupResponseFields.  # noqa: E501

        Id string in UUID format  # noqa: E501

        :return: The id of this GroupResponseFields.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GroupResponseFields.

        Id string in UUID format  # noqa: E501

        :param id: The id of this GroupResponseFields.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this GroupResponseFields.  # noqa: E501

        The name of the group  # noqa: E501

        :return: The name of this GroupResponseFields.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupResponseFields.

        The name of the group  # noqa: E501

        :param name: The name of this GroupResponseFields.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def created_on(self):
        """Gets the created_on of this GroupResponseFields.  # noqa: E501

        When the group was created  # noqa: E501

        :return: The created_on of this GroupResponseFields.  # noqa: E501
        :rtype: str
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this GroupResponseFields.

        When the group was created  # noqa: E501

        :param created_on: The created_on of this GroupResponseFields.  # noqa: E501
        :type: str
        """

        self._created_on = created_on

    @property
    def contacts_count(self):
        """Gets the contacts_count of this GroupResponseFields.  # noqa: E501

        The count of contacts in the group  # noqa: E501

        :return: The contacts_count of this GroupResponseFields.  # noqa: E501
        :rtype: int
        """
        return self._contacts_count

    @contacts_count.setter
    def contacts_count(self, contacts_count):
        """Sets the contacts_count of this GroupResponseFields.

        The count of contacts in the group  # noqa: E501

        :param contacts_count: The contacts_count of this GroupResponseFields.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and contacts_count is None:  # noqa: E501
            raise ValueError("Invalid value for `contacts_count`, must not be `None`")  # noqa: E501

        self._contacts_count = contacts_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupResponseFields):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GroupResponseFields):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.2.1"

# import apis into sdk package
from messente_api.api.blacklist_api import BlacklistApi
from messente_api.api.contacts_api import ContactsApi
from messente_api.api.delivery_report_api import DeliveryReportApi
from messente_api.api.groups_api import GroupsApi
from messente_api.api.number_lookup_api import NumberLookupApi
from messente_api.api.omnimessage_api import OmnimessageApi
from messente_api.api.statistics_api import StatisticsApi

# import ApiClient
from messente_api.api_client import ApiClient
from messente_api.configuration import Configuration
from messente_api.exceptions import OpenApiException
from messente_api.exceptions import ApiTypeError
from messente_api.exceptions import ApiValueError
from messente_api.exceptions import ApiKeyError
from messente_api.exceptions import ApiException
# import models into sdk package
from messente_api.models.channel import Channel
from messente_api.models.contact_envelope import ContactEnvelope
from messente_api.models.contact_fields import ContactFields
from messente_api.models.contact_list_envelope import ContactListEnvelope
from messente_api.models.contact_update_fields import ContactUpdateFields
from messente_api.models.delivery_report_response import DeliveryReportResponse
from messente_api.models.delivery_result import DeliveryResult
from messente_api.models.error_code_omnichannel import ErrorCodeOmnichannel
from messente_api.models.error_code_omnichannel_machine import ErrorCodeOmnichannelMachine
from messente_api.models.error_code_phonebook import ErrorCodePhonebook
from messente_api.models.error_code_statistics import ErrorCodeStatistics
from messente_api.models.error_item_number_lookup import ErrorItemNumberLookup
from messente_api.models.error_item_number_lookup_error import ErrorItemNumberLookupError
from messente_api.models.error_item_omnichannel import ErrorItemOmnichannel
from messente_api.models.error_item_phonebook import ErrorItemPhonebook
from messente_api.models.error_item_statistics import ErrorItemStatistics
from messente_api.models.error_number_lookup import ErrorNumberLookup
from messente_api.models.error_omnichannel import ErrorOmnichannel
from messente_api.models.error_phonebook import ErrorPhonebook
from messente_api.models.error_statistics import ErrorStatistics
from messente_api.models.error_title_omnichannel import ErrorTitleOmnichannel
from messente_api.models.error_title_phonebook import ErrorTitlePhonebook
from messente_api.models.fetch_blacklist_success import FetchBlacklistSuccess
from messente_api.models.group_envelope import GroupEnvelope
from messente_api.models.group_list_envelope import GroupListEnvelope
from messente_api.models.group_name import GroupName
from messente_api.models.group_response_fields import GroupResponseFields
from messente_api.models.message_result import MessageResult
from messente_api.models.mobile_network import MobileNetwork
from messente_api.models.number_to_blacklist import NumberToBlacklist
from messente_api.models.numbers_to_investigate import NumbersToInvestigate
from messente_api.models.omni_message_create_success_response import OmniMessageCreateSuccessResponse
from messente_api.models.omnimessage import Omnimessage
from messente_api.models.sms import SMS
from messente_api.models.statistics_report import StatisticsReport
from messente_api.models.statistics_report_settings import StatisticsReportSettings
from messente_api.models.statistics_report_success import StatisticsReportSuccess
from messente_api.models.status import Status
from messente_api.models.sync_number_lookup_result import SyncNumberLookupResult
from messente_api.models.sync_number_lookup_success import SyncNumberLookupSuccess
from messente_api.models.telegram import Telegram
from messente_api.models.text_store import TextStore
from messente_api.models.viber import Viber
from messente_api.models.whats_app import WhatsApp
from messente_api.models.whats_app_audio import WhatsAppAudio
from messente_api.models.whats_app_document import WhatsAppDocument
from messente_api.models.whats_app_image import WhatsAppImage
from messente_api.models.whats_app_text import WhatsAppText




# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class SMS(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'sender': 'str',
        'validity': 'int',
        'autoconvert': 'str',
        'udh': 'str',
        'channel': 'str'
    }

    attribute_map = {
        'text': 'text',
        'sender': 'sender',
        'validity': 'validity',
        'autoconvert': 'autoconvert',
        'udh': 'udh',
        'channel': 'channel'
    }

    def __init__(self, text=None, sender=None, validity=None, autoconvert=None, udh=None, channel='sms', local_vars_configuration=None):  # noqa: E501
        """SMS - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._sender = None
        self._validity = None
        self._autoconvert = None
        self._udh = None
        self._channel = None
        self.discriminator = None

        self.text = text
        if sender is not None:
            self.sender = sender
        if validity is not None:
            self.validity = validity
        if autoconvert is not None:
            self.autoconvert = autoconvert
        if udh is not None:
            self.udh = udh
        if channel is not None:
            self.channel = channel

    @property
    def text(self):
        """Gets the text of this SMS.  # noqa: E501

        Text content of the SMS  # noqa: E501

        :return: The text of this SMS.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SMS.

        Text content of the SMS  # noqa: E501

        :param text: The text of this SMS.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def sender(self):
        """Gets the sender of this SMS.  # noqa: E501

        Phone number or alphanumeric sender name  # noqa: E501

        :return: The sender of this SMS.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this SMS.

        Phone number or alphanumeric sender name  # noqa: E501

        :param sender: The sender of this SMS.  # noqa: E501
        :type: str
        """

        self._sender = sender

    @property
    def validity(self):
        """Gets the validity of this SMS.  # noqa: E501

        After how many minutes this channel is considered as failed and the next channel is attempted  # noqa: E501

        :return: The validity of this SMS.  # noqa: E501
        :rtype: int
        """
        return self._validity

    @validity.setter
    def validity(self, validity):
        """Sets the validity of this SMS.

        After how many minutes this channel is considered as failed and the next channel is attempted  # noqa: E501

        :param validity: The validity of this SMS.  # noqa: E501
        :type: int
        """

        self._validity = validity

    @property
    def autoconvert(self):
        """Gets the autoconvert of this SMS.  # noqa: E501

        Defines how non-GSM characters will be treated:    - \"on\" Use replacement settings from the account's [API Auto Replace settings page](https://dashboard.messente.com/api-settings/auto-replace) (default)   - \"full\" All non GSM 03.38 characters will be replaced with suitable alternatives   - \"off\" Message content is not modified in any way  # noqa: E501

        :return: The autoconvert of this SMS.  # noqa: E501
        :rtype: str
        """
        return self._autoconvert

    @autoconvert.setter
    def autoconvert(self, autoconvert):
        """Sets the autoconvert of this SMS.

        Defines how non-GSM characters will be treated:    - \"on\" Use replacement settings from the account's [API Auto Replace settings page](https://dashboard.messente.com/api-settings/auto-replace) (default)   - \"full\" All non GSM 03.38 characters will be replaced with suitable alternatives   - \"off\" Message content is not modified in any way  # noqa: E501

        :param autoconvert: The autoconvert of this SMS.  # noqa: E501
        :type: str
        """
        allowed_values = ["full", "on", "off"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and autoconvert not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `autoconvert` ({0}), must be one of {1}"  # noqa: E501
                .format(autoconvert, allowed_values)
            )

        self._autoconvert = autoconvert

    @property
    def udh(self):
        """Gets the udh of this SMS.  # noqa: E501

        hex-encoded string containing SMS UDH  # noqa: E501

        :return: The udh of this SMS.  # noqa: E501
        :rtype: str
        """
        return self._udh

    @udh.setter
    def udh(self, udh):
        """Sets the udh of this SMS.

        hex-encoded string containing SMS UDH  # noqa: E501

        :param udh: The udh of this SMS.  # noqa: E501
        :type: str
        """

        self._udh = udh

    @property
    def channel(self):
        """Gets the channel of this SMS.  # noqa: E501

        The channel used to deliver the message  # noqa: E501

        :return: The channel of this SMS.  # noqa: E501
        :rtype: str
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        """Sets the channel of this SMS.

        The channel used to deliver the message  # noqa: E501

        :param channel: The channel of this SMS.  # noqa: E501
        :type: str
        """
        allowed_values = ["sms"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and channel not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `channel` ({0}), must be one of {1}"  # noqa: E501
                .format(channel, allowed_values)
            )

        self._channel = channel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SMS):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SMS):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from messente_api.api.blacklist_api import BlacklistApi
from messente_api.api.contacts_api import ContactsApi
from messente_api.api.delivery_report_api import DeliveryReportApi
from messente_api.api.groups_api import GroupsApi
from messente_api.api.number_lookup_api import NumberLookupApi
from messente_api.api.omnimessage_api import OmnimessageApi
from messente_api.api.statistics_api import StatisticsApi



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from messente_api.api_client import ApiClient
from messente_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContactsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_contact_to_group(self, group_id, phone, **kwargs):  # noqa: E501
        """Adds a contact to a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_contact_to_group(group_id, phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: String in UUID format (required)
        :param str phone: A phone number (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_contact_to_group_with_http_info(group_id, phone, **kwargs)  # noqa: E501

    def add_contact_to_group_with_http_info(self, group_id, phone, **kwargs):  # noqa: E501
        """Adds a contact to a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_contact_to_group_with_http_info(group_id, phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: String in UUID format (required)
        :param str phone: A phone number (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'group_id',
            'phone'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_contact_to_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `add_contact_to_group`")  # noqa: E501
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `add_contact_to_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['groupId'] = local_var_params['group_id']  # noqa: E501
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/groups/{groupId}/contacts/{phone}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_contact(self, contact_fields, **kwargs):  # noqa: E501
        """Creates a new contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_contact(contact_fields, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ContactFields contact_fields: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContactEnvelope
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_contact_with_http_info(contact_fields, **kwargs)  # noqa: E501

    def create_contact_with_http_info(self, contact_fields, **kwargs):  # noqa: E501
        """Creates a new contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_contact_with_http_info(contact_fields, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ContactFields contact_fields: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContactEnvelope, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'contact_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_contact" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'contact_fields' is set
        if self.api_client.client_side_validation and ('contact_fields' not in local_var_params or  # noqa: E501
                                                        local_var_params['contact_fields'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contact_fields` when calling `create_contact`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contact_fields' in local_var_params:
            body_params = local_var_params['contact_fields']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContactEnvelope',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_contact(self, phone, **kwargs):  # noqa: E501
        """Deletes a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_contact(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_contact_with_http_info(phone, **kwargs)  # noqa: E501

    def delete_contact_with_http_info(self, phone, **kwargs):  # noqa: E501
        """Deletes a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_contact_with_http_info(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_contact" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `delete_contact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts/{phone}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_contact(self, phone, **kwargs):  # noqa: E501
        """Lists a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contact(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContactEnvelope
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.fetch_contact_with_http_info(phone, **kwargs)  # noqa: E501

    def fetch_contact_with_http_info(self, phone, **kwargs):  # noqa: E501
        """Lists a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contact_with_http_info(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContactEnvelope, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_contact" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `fetch_contact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts/{phone}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContactEnvelope',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_contact_groups(self, phone, **kwargs):  # noqa: E501
        """Lists groups of a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contact_groups(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GroupListEnvelope
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.fetch_contact_groups_with_http_info(phone, **kwargs)  # noqa: E501

    def fetch_contact_groups_with_http_info(self, phone, **kwargs):  # noqa: E501
        """Lists groups of a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contact_groups_with_http_info(phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GroupListEnvelope, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_contact_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `fetch_contact_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts/{phone}/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupListEnvelope',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_contacts(self, **kwargs):  # noqa: E501
        """Returns all contacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contacts(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] group_ids: Optional one or many group id strings in UUID format. For example: \"/contacts?groupIds=group_id_one&groupIds=group_id_two\" 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContactListEnvelope
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.fetch_contacts_with_http_info(**kwargs)  # noqa: E501

    def fetch_contacts_with_http_info(self, **kwargs):  # noqa: E501
        """Returns all contacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_contacts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] group_ids: Optional one or many group id strings in UUID format. For example: \"/contacts?groupIds=group_id_one&groupIds=group_id_two\" 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContactListEnvelope, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'group_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_contacts" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in local_var_params and local_var_params['group_ids'] is not None:  # noqa: E501
            query_params.append(('groupIds', local_var_params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContactListEnvelope',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_contact_from_group(self, group_id, phone, **kwargs):  # noqa: E501
        """Removes a contact from a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_contact_from_group(group_id, phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: String in UUID format (required)
        :param str phone: A phone number (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_contact_from_group_with_http_info(group_id, phone, **kwargs)  # noqa: E501

    def remove_contact_from_group_with_http_info(self, group_id, phone, **kwargs):  # noqa: E501
        """Removes a contact from a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_contact_from_group_with_http_info(group_id, phone, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: String in UUID format (required)
        :param str phone: A phone number (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'group_id',
            'phone'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_contact_from_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `remove_contact_from_group`")  # noqa: E501
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `remove_contact_from_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['groupId'] = local_var_params['group_id']  # noqa: E501
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/groups/{groupId}/contacts/{phone}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_contact(self, phone, contact_update_fields, **kwargs):  # noqa: E501
        """Updates a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_contact(phone, contact_update_fields, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param ContactUpdateFields contact_update_fields: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContactEnvelope
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_contact_with_http_info(phone, contact_update_fields, **kwargs)  # noqa: E501

    def update_contact_with_http_info(self, phone, contact_update_fields, **kwargs):  # noqa: E501
        """Updates a contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_contact_with_http_info(phone, contact_update_fields, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str phone: A phone number (required)
        :param ContactUpdateFields contact_update_fields: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContactEnvelope, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'phone',
            'contact_update_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_contact" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'phone' is set
        if self.api_client.client_side_validation and ('phone' not in local_var_params or  # noqa: E501
                                                        local_var_params['phone'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `phone` when calling `update_contact`")  # noqa: E501
        # verify the required parameter 'contact_update_fields' is set
        if self.api_client.client_side_validation and ('contact_update_fields' not in local_var_params or  # noqa: E501
                                                        local_var_params['contact_update_fields'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contact_update_fields` when calling `update_contact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'phone' in local_var_params:
            path_params['phone'] = local_var_params['phone']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contact_update_fields' in local_var_params:
            body_params = local_var_params['contact_update_fields']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/phonebook/contacts/{phone}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContactEnvelope',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class Telegram(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sender': 'str',
        'validity': 'int',
        'text': 'str',
        'image_url': 'str',
        'document_url': 'str',
        'audio_url': 'str',
        'channel': 'str'
    }

    attribute_map = {
        'sender': 'sender',
        'validity': 'validity',
        'text': 'text',
        'image_url': 'image_url',
        'document_url': 'document_url',
        'audio_url': 'audio_url',
        'channel': 'channel'
    }

    def __init__(self, sender=None, validity=None, text=None, image_url=None, document_url=None, audio_url=None, channel='telegram', local_vars_configuration=None):  # noqa: E501
        """Telegram - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sender = None
        self._validity = None
        self._text = None
        self._image_url = None
        self._document_url = None
        self._audio_url = None
        self._channel = None
        self.discriminator = None

        if sender is not None:
            self.sender = sender
        if validity is not None:
            self.validity = validity
        if text is not None:
            self.text = text
        if image_url is not None:
            self.image_url = image_url
        if document_url is not None:
            self.document_url = document_url
        if audio_url is not None:
            self.audio_url = audio_url
        if channel is not None:
            self.channel = channel

    @property
    def sender(self):
        """Gets the sender of this Telegram.  # noqa: E501

        Phone number or alphanumeric sender name  # noqa: E501

        :return: The sender of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this Telegram.

        Phone number or alphanumeric sender name  # noqa: E501

        :param sender: The sender of this Telegram.  # noqa: E501
        :type: str
        """

        self._sender = sender

    @property
    def validity(self):
        """Gets the validity of this Telegram.  # noqa: E501

        After how many minutes this channel is considered as failed and the next channel is attempted  # noqa: E501

        :return: The validity of this Telegram.  # noqa: E501
        :rtype: int
        """
        return self._validity

    @validity.setter
    def validity(self, validity):
        """Sets the validity of this Telegram.

        After how many minutes this channel is considered as failed and the next channel is attempted  # noqa: E501

        :param validity: The validity of this Telegram.  # noqa: E501
        :type: int
        """

        self._validity = validity

    @property
    def text(self):
        """Gets the text of this Telegram.  # noqa: E501

        Plaintext content for Telegram  # noqa: E501

        :return: The text of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Telegram.

        Plaintext content for Telegram  # noqa: E501

        :param text: The text of this Telegram.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def image_url(self):
        """Gets the image_url of this Telegram.  # noqa: E501

        URL for the embedded image. Mutually exclusive with \"document_url\" and \"audio_url\"  # noqa: E501

        :return: The image_url of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this Telegram.

        URL for the embedded image. Mutually exclusive with \"document_url\" and \"audio_url\"  # noqa: E501

        :param image_url: The image_url of this Telegram.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    @property
    def document_url(self):
        """Gets the document_url of this Telegram.  # noqa: E501

        URL for the embedded image. Mutually exclusive with \"audio_url\" and \"image_url\"  # noqa: E501

        :return: The document_url of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this Telegram.

        URL for the embedded image. Mutually exclusive with \"audio_url\" and \"image_url\"  # noqa: E501

        :param document_url: The document_url of this Telegram.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    @property
    def audio_url(self):
        """Gets the audio_url of this Telegram.  # noqa: E501

        URL for the embedded image. Mutually exclusive with \"document_url\" and \"image_url\"  # noqa: E501

        :return: The audio_url of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._audio_url

    @audio_url.setter
    def audio_url(self, audio_url):
        """Sets the audio_url of this Telegram.

        URL for the embedded image. Mutually exclusive with \"document_url\" and \"image_url\"  # noqa: E501

        :param audio_url: The audio_url of this Telegram.  # noqa: E501
        :type: str
        """

        self._audio_url = audio_url

    @property
    def channel(self):
        """Gets the channel of this Telegram.  # noqa: E501

        The channel used to deliver the message  # noqa: E501

        :return: The channel of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        """Sets the channel of this Telegram.

        The channel used to deliver the message  # noqa: E501

        :param channel: The channel of this Telegram.  # noqa: E501
        :type: str
        """
        allowed_values = ["telegram"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and channel not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `channel` ({0}), must be one of {1}"  # noqa: E501
                .format(channel, allowed_values)
            )

        self._channel = channel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Telegram):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Telegram):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from messente_api.configuration import Configuration


class ContactUpdateFields(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'company': 'str',
        'title': 'str',
        'custom': 'str',
        'custom2': 'str',
        'custom3': 'str',
        'custom4': 'str'
    }

    attribute_map = {
        'email': 'email',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'company': 'company',
        'title': 'title',
        'custom': 'custom',
        'custom2': 'custom2',
        'custom3': 'custom3',
        'custom4': 'custom4'
    }

    def __init__(self, email=None, first_name=None, last_name=None, company=None, title=None, custom=None, custom2=None, custom3=None, custom4=None, local_vars_configuration=None):  # noqa: E501
        """ContactUpdateFields - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email = None
        self._first_name = None
        self._last_name = None
        self._company = None
        self._title = None
        self._custom = None
        self._custom2 = None
        self._custom3 = None
        self._custom4 = None
        self.discriminator = None

        self.email = email
        self.first_name = first_name
        self.last_name = last_name
        self.company = company
        self.title = title
        self.custom = custom
        self.custom2 = custom2
        self.custom3 = custom3
        self.custom4 = custom4

    @property
    def email(self):
        """Gets the email of this ContactUpdateFields.  # noqa: E501

        The email of the contact  # noqa: E501

        :return: The email of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ContactUpdateFields.

        The email of the contact  # noqa: E501

        :param email: The email of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this ContactUpdateFields.  # noqa: E501

        The first name of the contact  # noqa: E501

        :return: The first_name of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ContactUpdateFields.

        The first name of the contact  # noqa: E501

        :param first_name: The first_name of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ContactUpdateFields.  # noqa: E501

        The last name of the contact  # noqa: E501

        :return: The last_name of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ContactUpdateFields.

        The last name of the contact  # noqa: E501

        :param last_name: The last_name of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def company(self):
        """Gets the company of this ContactUpdateFields.  # noqa: E501

        The company of the contact  # noqa: E501

        :return: The company of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this ContactUpdateFields.

        The company of the contact  # noqa: E501

        :param company: The company of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def title(self):
        """Gets the title of this ContactUpdateFields.  # noqa: E501

        The title of the contact  # noqa: E501

        :return: The title of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ContactUpdateFields.

        The title of the contact  # noqa: E501

        :param title: The title of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def custom(self):
        """Gets the custom of this ContactUpdateFields.  # noqa: E501

        The first custom field  # noqa: E501

        :return: The custom of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._custom

    @custom.setter
    def custom(self, custom):
        """Sets the custom of this ContactUpdateFields.

        The first custom field  # noqa: E501

        :param custom: The custom of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._custom = custom

    @property
    def custom2(self):
        """Gets the custom2 of this ContactUpdateFields.  # noqa: E501

        The second custom field  # noqa: E501

        :return: The custom2 of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._custom2

    @custom2.setter
    def custom2(self, custom2):
        """Sets the custom2 of this ContactUpdateFields.

        The second custom field  # noqa: E501

        :param custom2: The custom2 of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._custom2 = custom2

    @property
    def custom3(self):
        """Gets the custom3 of this ContactUpdateFields.  # noqa: E501

        The third custom field  # noqa: E501

        :return: The custom3 of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._custom3

    @custom3.setter
    def custom3(self, custom3):
        """Sets the custom3 of this ContactUpdateFields.

        The third custom field  # noqa: E501

        :param custom3: The custom3 of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._custom3 = custom3

    @property
    def custom4(self):
        """Gets the custom4 of this ContactUpdateFields.  # noqa: E501

        The fourth custom field  # noqa: E501

        :return: The custom4 of this ContactUpdateFields.  # noqa: E501
        :rtype: str
        """
        return self._custom4

    @custom4.setter
    def custom4(self, custom4):
        """Sets the custom4 of this ContactUpdateFields.

        The fourth custom field  # noqa: E501

        :param custom4: The custom4 of this ContactUpdateFields.  # noqa: E501
        :type: str
        """

        self._custom4 = custom4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactUpdateFields):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContactUpdateFields):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Messente API

    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you're not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: messente@messente.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "messente-api"
VERSION = "1.2.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Messente API",
    author="Messente",
    author_email="messente@messente.com",
    url="https://github.com/messente/messente-api-python",
    keywords=["viber", "sms", "whatsapp", "phonebook"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache-2.0",
    long_description="""\
    [Messente](https://messente.com) is a global provider of messaging and user verification services.  * Send and receive SMS, Viber, WhatsApp and Telegram messages. * Manage contacts and groups. * Fetch detailed info about phone numbers. * Blacklist phone numbers to make sure you&#39;re not sending any unwanted messages.  Messente builds [tools](https://messente.com/documentation) to help organizations connect their services to people anywhere in the world.  # noqa: E501
    """,
    long_description_content_type="text/markdown"
)
